==> spread-5.2.0.24-py3-none-any.whl: spread_core/mqtt/spread/variable.py <==
import json
from datetime import datetime

from spread_core.tools.settings import config, USE_TIMESTAMP


class Variable:
    PRELIM = 'preliminary'
    TS = 'timestamp'

    def __init__(self, value, timestamp: datetime = None, invalid=False, sig=None, key=None, session=None, params=None,
                 inconsistent=False, preliminary=False):
        if value == 'false':
            value = False
        elif value == 'true':
            value = True

        self._value = value
        self._invalid = invalid or value is None
        self._inconsistent = inconsistent
        self._preliminary = preliminary
        if sig:
            self._key = sig.key
            self._session_id = sig.session_id
        else:
            self._key = key
            self._session_id = session
        self._params = params if params else {}

        if isinstance(timestamp, str):
            self._timestamp = datetime.fromisoformat(timestamp)
        elif timestamp is None:
            self._timestamp = datetime.now()
        else:
            self._timestamp = timestamp

    value = property(fget=lambda self: self._value, doc='value')
    timestamp = property(fget=lambda self: self._timestamp, doc='timestamp')
    invalid = property(fget=lambda self: self._invalid, doc='invalid')
    inconsistent = property(fget=lambda self: self._inconsistent, doc='inconsistent')

    def clear_signature(self):
        self._key = None
        self._session_id = None

    @property
    def key(self): return self._key

    @key.setter
    def key(self, key): self._key = key

    @property
    def session_id(self): return self._session_id

    @session_id.setter
    def session_id(self, session): self._session_id = str(session)

    @property
    def params(self): return self._params

    @property
    def preliminary(self): return self._preliminary

    @classmethod
    def of(cls, data: (dict, bytes, str)):
        if isinstance(data, (bytes, bytearray)):
            if data:
                data = data.decode()
            else:
                data = {'value': None}

        if isinstance(data, str):
            data = json.loads(data)

        return cls(
            value=data.pop('value', None),
            timestamp=data.pop(cls.TS, None),
            invalid=data.pop('invalid', False),
            session=data.pop('session', None),
            key=data.pop('key', None),
            params=data.pop('params', {}),
            preliminary=data.pop(cls.PRELIM, False)
        )

    def __str__(self):
        return ('(Inv) ' if self.invalid else '') + \
               ('(Pr) ' if self._preliminary else '') + \
               (f'{self._value}'.ljust(11, " ") if self.value is not None else '') + \
               (' ' + '; '.join([f'{key}={value}' for key, value in self.params.items()]) if self.params else '')

    def __iter__(self):
        data = dict()

        if self.value is not None: data['value'] = self._value
        if self.params: data['params'] = self.params
        if self._invalid: data['invalid'] = True
        if self._inconsistent: data['inconsistent'] = True
        if self._preliminary: data[self.PRELIM] = self._preliminary
        if self.key: data['key'] = self.key
        if self.session_id: data['session'] = self.session_id
        return data

    def pack(self, **kwargs):
        data = self.__iter__()

        if config.get(USE_TIMESTAMP, True) or 'timestamp' in kwargs:
            data['timestamp'] = self._timestamp.astimezone().isoformat()

        return json.dumps(data)

==> spread-5.3.0.5-py3-none-any.whl: spread_core/mqtt/spread/variable.py <==
import json
from datetime import datetime

from spread_core.tools.settings import config, USE_TIMESTAMP


class Variable:
    PRELIM = 'preliminary'
    TS = 'timestamp'

    def __init__(self, value, timestamp: datetime = None, invalid=False, sig=None, key=None, session=None, params=None,
                 inconsistent=False, preliminary=False, error=None):
        if value == 'false':
            value = False
        elif value == 'true':
            value = True

        self._value = value
        self._invalid = invalid or value is None
        self._inconsistent = inconsistent
        self._preliminary = preliminary
        if sig:
            self._key = sig.key
            self._session_id = sig.session_id
        else:
            self._key = key
            self._session_id = session
        self._params = params if params else {}

        if isinstance(timestamp, str):
            self._timestamp = datetime.fromisoformat(timestamp)
        elif timestamp is None:
            self._timestamp = datetime.now()
        else:
            self._timestamp = timestamp

        self._error = error

    value = property(fget=lambda self: self._value, doc='value')
    timestamp = property(fget=lambda self: self._timestamp, doc='timestamp')
    invalid = property(fget=lambda self: self._invalid, doc='invalid')
    inconsistent = property(fget=lambda self: self._inconsistent, doc='inconsistent')

    def clear_signature(self):
        self._key = None
        self._session_id = None

    @property
    def key(self): return self._key

    @key.setter
    def key(self, key): self._key = key

    @property
    def session_id(self): return self._session_id

    @session_id.setter
    def session_id(self, session): self._session_id = str(session)

    @property
    def params(self): return self._params

    @property
    def preliminary(self): return self._preliminary

    @classmethod
    def of(cls, data: (dict, bytes, str)):
        if isinstance(data, (bytes, bytearray)):
            if data:
                data = data.decode()
            else:
                data = {'value': None}

        if isinstance(data, str):
            data = json.loads(data)

        return cls(
            value=data.pop('value', None),
            timestamp=data.pop(cls.TS, None),
            invalid=data.pop('invalid', False),
            session=data.pop('session', None),
            key=data.pop('key', None),
            params=data.pop('params', {}),
            preliminary=data.pop(cls.PRELIM, False)
        )

    def __str__(self):
        return ('(Inv) ' if self.invalid else '') + \
               ('(Pr) ' if self._preliminary else '') + \
               (f'{self._value}'.ljust(11, " ") if self.value is not None else '') + \
               (' ' + '; '.join([f'{key}={value}' for key, value in self.params.items()]) if self.params else '')

    def __iter__(self):
        data = dict()

        if self.value is not None: data['value'] = self._value
        if self.params: data['params'] = self.params
        if self._invalid: data['invalid'] = True
        if self._inconsistent: data['inconsistent'] = True
        if self._preliminary: data[self.PRELIM] = self._preliminary
        if self.key: data['key'] = self.key
        if self.session_id: data['session'] = self.session_id
        if self._error: data['error'] = self._error
        return data

    def pack(self, **kwargs):
        data = self.__iter__()

        if config.get(USE_TIMESTAMP, True) or 'timestamp' in kwargs:
            data['timestamp'] = self._timestamp.astimezone().isoformat()

        return json.dumps(data)
